@@ -11,11 +11,11 @@ class normalizer {
     public:
         normalizer(real _min, real _max, real _Min, real _Max);
 
-        real    normalize(real  r);
-        real*   normalize(real *r, int size);
+        real normalize(real  r);
+        real denormalize(real  r);
 
-        real  denormalize(real  r);
-        real* denormalize(real *r, int size);
+        void normalize(real *r, int size);
+        void denormalize(real *r, int size);
 };
 
 #endif
