@@ -16,12 +16,12 @@ real normalizer::denormalize(real r) {
     return (r*Max - r*Min + Min*max - min*Max)/(max - min);
 }
 
-real *normalizer::normalize(real *r, int size) {
+void normalizer::normalize(real *r, int size) {
     for(int i=0; i<size; i++)
         r[i] = normalize(r[i]);
 }
 
-real *normalizer::denormalize(real *r, int size) {
+void normalizer::denormalize(real *r, int size) {
     for(int i=0; i<size; i++)
         r[i] = denormalize(r[i]);
 }
